@@ -9,7 +9,8 @@ use Class::MethodMaker [
                         scalar => [ qw( qnames x ) ],
                        ];
 
-my $VERSION = 1.31;
+our
+$VERSION = 1.31;
 
 sub new {
     my ($class, $attrs) = @_;
