@@ -8,7 +8,8 @@ use Class::MethodMaker [
                         scalar => [ qw/ base subject language URI qname attrs parent children xtext text / ],
                        ];
 
-my $VERSION = 1.31;
+our
+$VERSION = 1.31;
 
 sub new {
     my ($class,$ns,$prefix,$name,$parent,$attrs,%p) = @_;
